@@ -58,4 +58,9 @@ int ChannelController::subCount() const
     return m_channel.subCount();
 }
 
-#include "moc_channelcontroller.cpp"
\ No newline at end of file
+QString ChannelController::url() const
+{
+    return m_channel.url();
+}
+
+#include "moc_channelcontroller.cpp"
